<?php

require_once 'orm/mapping/OrmMapElementCollection.php';

/**
 * Many to many (m2m) relations map's element class.
 * 
 * This class defines map's element for M2m relations.
 * This element represents a m2m (usually marked as m:n) relation.
 * 
 * @author  $Author: pruna $
 * @package orm/mapping
 * @version $Revision: 1.3 $
 * @created 02-Apr-2005
 * @modified $Date: 2005/12/06 02:56:45 $
 */
class OrmMapElementM2m extends OrmMapElementCollection {
    
    /**
     * Constructor that defines basic properties for this Bean.
     * 
     * It follows Collection rules for constructor.
     * Basic elements are: 
     * <ul>
     * <li>update: if must update (boolean - default: true)</li>
     * <li>insert: if must insert (boolean - default: true)</li>
     * <li>pivotTable: name of auxiliar table for m:n relations (string)</li>
     * <li>pivotColumnPk: pk field on pivot (string)</li>
     * <li>pivotToLeft: field on pivot pointing back (string)</li>
     * <li>pivotToRight: field on pivot pointing forward (string)</li>
     * <li>cascadePivot: list of actions to cascade to pivot (string)</li>
     * </ul>
     * Default values may serve as guide for preferred data types.
     * For a full description about this elements, see @docs
     * 
     * @access  public
     * @param   ICollection    $collection    Initial elements
     */
    public function __construct($collection = null) {
        parent::__construct(array(
            'update' => TRUE,
            'insert' => TRUE,
            'pivotTable' => null,
            'pivotColumnPk' => null,
            'pivotToLeft' => null,
            'pivotToRight' => null,
            'cascadePivot' => array(),
        ));
        $this->setAll($collection);
    }
   
}

?>